// SPDX-License-Identifier: Apache-2.0
pragma solidity ^0.8.0;

import "./interface/IContractMetadata.sol";

abstract contract ContractMetadata is IContractMetadata {
    /// @dev Contract level metadata.
    string public override contractURI;

    /// @dev Lets a contract admin set the URI for contract-level metadata.
    function setContractURI(string memory _uri) public override {
        require(_canSetContractURI(), "Not authorized");
        string memory prevURI = contractURI;
        contractURI = _uri;

        emit ContractURIUpdated(prevURI, _uri);
    }

    /// @dev Returns whether contract metadata can be set in the given execution context.
    function _canSetContractURI() internal virtual returns (bool);
}
